==> haskell-ptr-0.16.8.7-121.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-L0jN3nXgiI8CXCoCBTc7ze
key:                  ptr-0.16.8.7-L0jN3nXgiI8CXCoCBTc7ze
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  d160d725a3c15a2f605578ed2fb7da7f
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-L0jN3nXgiI8CXCoCBTc7ze
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    strict-list-0.1.7.6-JIfe1DsCbLp7n7ZCmVBiDO text-2.0.2 time-1.12.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ptr-0.16.8.7-122-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-DnBX4kqQ09cIxCUhB1J36g
key:                  ptr-0.16.8.7-DnBX4kqQ09cIxCUhB1J36g
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  d2e468d8fbeadc1b8af978f4e60640cd
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-DnBX4kqQ09cIxCUhB1J36g
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    strict-list-0.1.7.6-33IElGv1emkKg5CjRd99pG text-2.0.2 time-1.12.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
